@@ -1,6 +1,6 @@
 #
 # -
-# Copyright (c) 2014, 2015, 2019, 2020  StorPool.
+# Copyright (c) 2014, 2015, 2019 - 2021  StorPool.
 # All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -256,7 +256,12 @@ class AttachDB(splocked.SPLockedJSONDB):
                     )
                 break
             except spapi.ApiError as e:
-                if e.name == "invalidParam" and "is open at" in e.desc:
+                if (
+                    e.name in ("busy", "invalidParam")
+                    and "is open at" in e.desc
+                ):
                     assert count > 0
                     time.sleep(0.2)
                     count -= 1
+                else:
+                    raise
